@@ -32,10 +32,10 @@ def search(symbolo):
       elif isinstance(c_element[1],int):#Si tenemos un float
           return "("+str(c_element[1])+")"
       elif c_element[1] != None:#Si tenemos una expresión
-          return sympy.latex(c_element[1])
+          return "("+sympy.latex(c_element[1])+")"
       else:
-        return sy.latex(symbolo)#Si es None
-  return sy.latex(symbolo)
+        return sympy.latex(symbolo)#Si es None
+  return sympy.latex(symbolo)
 
 def Redondear(expr):#Redondeamos la expresión.
   if isinstance(expr, sympy.Expr) or isinstance(expr, sympy.Float):
